use std::net::Ipv4Addr;
use std::net::Ipv6Addr;

/// Resolves a NAT64 address if it is in the range of 64:ff9b::/96
pub fn resolve_nat64_address(from: Ipv6Addr) -> Option<Ipv4Addr> {
	if is_nat64_address(&from) {
		let segments = from.segments();
		return Some(Ipv4Addr::new(
			((segments[6] & 0xff00) >> 8) as u8,
			(segments[6] & 0x00ff) as u8,
			((segments[7] & 0xff00) >> 8) as u8,
			(segments[7] & 0x00ff) as u8,
		));
	} else {
		return None;
	}
}

pub fn is_nat64_address(address: &Ipv6Addr) -> bool {
	let segments = address.segments();
	segments[0]==0x64 && segments[1]==0xff9b
}

